aboutsummaryrefslogtreecommitdiff
path: root/test/functional/feature_framework_miniwallet.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/functional/feature_framework_miniwallet.py')
-rwxr-xr-xtest/functional/feature_framework_miniwallet.py36
1 files changed, 26 insertions, 10 deletions
diff --git a/test/functional/feature_framework_miniwallet.py b/test/functional/feature_framework_miniwallet.py
index f108289018..f723f7f31e 100755
--- a/test/functional/feature_framework_miniwallet.py
+++ b/test/functional/feature_framework_miniwallet.py
@@ -3,10 +3,13 @@
# Distributed under the MIT software license, see the accompanying
# file COPYING or http://www.opensource.org/licenses/mit-license.php.
"""Test MiniWallet."""
+import random
+import string
+
from test_framework.blocktools import COINBASE_MATURITY
from test_framework.test_framework import BitcoinTestFramework
from test_framework.util import (
- assert_greater_than_or_equal,
+ assert_equal,
)
from test_framework.wallet import (
MiniWallet,
@@ -19,17 +22,29 @@ class FeatureFrameworkMiniWalletTest(BitcoinTestFramework):
self.num_nodes = 1
def test_tx_padding(self):
- """Verify that MiniWallet's transaction padding (`target_weight` parameter)
- works accurately enough (i.e. at most 3 WUs higher) with all modes."""
+ """Verify that MiniWallet's transaction padding (`target_vsize` parameter)
+ works accurately with all modes."""
for mode_name, wallet in self.wallets:
self.log.info(f"Test tx padding with MiniWallet mode {mode_name}...")
utxo = wallet.get_utxo(mark_as_spent=False)
- for target_weight in [1000, 2000, 5000, 10000, 20000, 50000, 100000, 200000, 4000000,
- 989, 2001, 4337, 13371, 23219, 49153, 102035, 223419, 3999989]:
- tx = wallet.create_self_transfer(utxo_to_spend=utxo, target_weight=target_weight)["tx"]
- self.log.debug(f"-> target weight: {target_weight}, actual weight: {tx.get_weight()}")
- assert_greater_than_or_equal(tx.get_weight(), target_weight)
- assert_greater_than_or_equal(target_weight + 3, tx.get_weight())
+ for target_vsize in [250, 500, 1250, 2500, 5000, 12500, 25000, 50000, 1000000,
+ 248, 501, 1085, 3343, 5805, 12289, 25509, 55855, 999998]:
+ tx = wallet.create_self_transfer(utxo_to_spend=utxo, target_vsize=target_vsize)["tx"]
+ assert_equal(tx.get_vsize(), target_vsize)
+
+ def test_wallet_tagging(self):
+ """Verify that tagged wallet instances are able to send funds."""
+ self.log.info(f"Test tagged wallet instances...")
+ node = self.nodes[0]
+ untagged_wallet = self.wallets[0][1]
+ for i in range(10):
+ tag = ''.join(random.choice(string.ascii_letters) for _ in range(20))
+ self.log.debug(f"-> ({i}) tag name: {tag}")
+ tagged_wallet = MiniWallet(node, tag_name=tag)
+ untagged_wallet.send_to(from_node=node, scriptPubKey=tagged_wallet.get_scriptPubKey(), amount=100000)
+ tagged_wallet.rescan_utxos()
+ tagged_wallet.send_self_transfer(from_node=node)
+ self.generate(node, 1) # clear mempool
def run_test(self):
node = self.nodes[0]
@@ -43,7 +58,8 @@ class FeatureFrameworkMiniWalletTest(BitcoinTestFramework):
self.generate(wallet, COINBASE_MATURITY)
self.test_tx_padding()
+ self.test_wallet_tagging()
if __name__ == '__main__':
- FeatureFrameworkMiniWalletTest().main()
+ FeatureFrameworkMiniWalletTest(__file__).main()